==> gitlab_16.11.6.orig.tar.bz2: gitlab-foss-v16.11.6/.gitlab/issue_templates/Web IDE Category - issue.md <==
MR: Pending
<!--
The first line of this issue description must be one of the following:

1. `MR: Pending`
2. `MR: <MR link with trailing +>`,
3. If there are multiple MRs:
   ```
   MRs:
   - <MR 1 link with trailing +>`
   - <MR 2 link with trailing +>`
   - ...
   ```
4. `MR: No MR`

...and the first description line of the MR should be `Issue: <Issue link with trailing +>` 

For more context, see:
https://about.gitlab.com/handbook/engineering/development/dev/create/ide/index.html#relationship-of-issues-to-mrs
-->

<!--
The following sections should be filled out as part of the refinement process before the issue is prioritized.

For more context, see:
https://about.gitlab.com/handbook/engineering/development/dev/create/ide/#2-pre-iteration-planning-meeting
-->

## Description

TODO: Fill out (required)

As a [user or stakeholder], I want [goal or objective] so that [reason or benefit].

[Provide any additional description here.]

## Acceptance Criteria

TODO: Fill out (required)
- [ ] [Describe what must be achieved to complete this issue.]
- [ ] [Describe another requirement needed to complete this issue.]
- [ ] [Add additional acceptance criteria as needed.]

## Technical Requirements

TODO: Fill out or delete (optional)
[If applicable, please list out any technical requirements for this feature/enhancement.]

## Design Requirements

TODO: Fill out or delete (optional)
[If applicable, please provide a link to the design specifications for this feature/enhancement.]

## Impact Assessment

TODO: Fill out or delete (optional)
[Please describe the impact this feature/enhancement will have on the user experience and/or the product as a whole.]

## User Story

TODO: Fill out or delete (optional)
[Provide a user story to illustrate the use case for this feature/enhancement. Include examples to help communicate the intended functionality.]


/label ~"Category:Web IDE"
/label  ~"section::dev"
/label  ~"devops::create"
/label  ~"group::ide"

<!-- Replace with other type, e.g. bug or maintenance, if appropriate -->
/label ~"type::feature"
<!-- Replace with other subtype if appropriate -->
/label ~"feature::addition"

<!-- By default, all issues start in the unprioritized status. See https://about.gitlab.com/handbook/engineering/development/dev/create/ide/#-remote-development-planning-process -->
/label  ~"rd-workflow::unprioritized"

<!-- For simplicity and to avoid triage bot warnings about missing workflow labels, we will default to issues starting at the refinement phase --> 
/label ~"workflow::refinement"

==> gitlab_17.6.5.orig.tar.bz2: gitlab-foss-v17.6.5/.gitlab/issue_templates/Web IDE Category - issue.md <==
MR: Pending

<!--
The first line of this issue description must be one of the following:

1. `MR: Pending`
2. `MR: <MR link with trailing +>`,
3. If there are multiple MRs:
   ```
   MRs:
   - <MR 1 link with trailing +>`
   - <MR 2 link with trailing +>`
   - ...
   ```
4. `MR: No MR`

...and the first description line of the MR should be `Issue: <Issue link with trailing +>`

For more context, see:
https://handbook.gitlab.com/handbook/engineering/development/dev/create/remote-development/#relationship-of-issues-to-mrs
-->

<!--
The following sections should be filled out as part of the refinement process before the issue is prioritized.

For more context, see:
https://handbook.gitlab.com/handbook/engineering/development/dev/create/remote-development/#2-pre-iteration-planning-meeting
-->

## Description

TODO: Fill out (required)

As a [user or stakeholder], I want [goal or objective] so that [reason or benefit].

[Provide any additional description here.]

## Acceptance Criteria

TODO: Fill out (required)

- [ ] [Describe what must be achieved to complete this issue.]
- [ ] [Describe another requirement needed to complete this issue.]
- [ ] [Add additional acceptance criteria as needed.]

## Technical Requirements

TODO: Fill out or delete (optional)
[If applicable, please list out any technical requirements for this feature/enhancement.]

## Design Requirements

TODO: Fill out or delete (optional)
[If applicable, please provide a link to the design specifications for this feature/enhancement.]

## Impact Assessment

TODO: Fill out or delete (optional)
[Please describe the impact this feature/enhancement will have on the user experience and/or the product as a whole.]

## User Story

TODO: Fill out or delete (optional)
[Provide a user story to illustrate the use case for this feature/enhancement. Include examples to help communicate the intended functionality.]

/label ~"Category:Web IDE"
/label ~"section::dev"
/label ~"devops::create"
/label ~"group::remote development"

<!-- Replace with other type, e.g. bug or maintenance, if appropriate -->

/label ~"type::feature"

<!-- Replace with other subtype if appropriate -->

/label ~"feature::addition"

<!-- By default, all issues start in the unprioritized status. See https://handbook.gitlab.com/handbook/engineering/development/dev/create/remote-development/#-planning-process -->

/label ~"webide-workflow::unprioritized"

<!-- For simplicity and to avoid triage bot warnings about missing workflow labels, we will default to issues starting at the refinement phase -->

/label ~"workflow::refinement"
